@@ -18,7 +18,7 @@ package PkgConfig::UDefs;
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.07120';
+our $VERSION = '0.07520';
 
 require 5.006;
 
@@ -26,6 +26,7 @@ use strict;
 use warnings;
 use Config;
 use File::Spec;
+use File::Glob 'bsd_glob';
 use Class::Struct; #in core since 5.004
 our $UseDebugging;
 
@@ -67,6 +68,7 @@ our @DEFAULT_SEARCH_PATH = qw(
 if($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
     if(-x "/usr/bin/dpkg-architecture") {
         my $arch = `/usr/bin/dpkg-architecture -qDEB_HOST_MULTIARCH`;
+        chomp $arch;
         @DEFAULT_SEARCH_PATH = (
             "/usr/local/lib/$arch/pkgconfig",
             "/usr/local/lib/pkgconfig",
@@ -124,6 +126,32 @@ if($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
         /usr/X11R6/lib/pkgconfig
         /usr/X11R6/share/pkgconfig
     );
+
+} elsif($^O eq 'MSWin32') {
+
+    # Caveats:
+    # 1. This pulls in Config,
+    #    which we don't load on non MSWin32
+    #    but it is in the core.
+    # 2. Slight semantic difference in that we are treating
+    #    Strawberry as the "system" rather than Windows, but
+    #    since pkg-config is rarely used in MSWin32, it is
+    #    better to have something that is useful rather than
+    #    worry about if it is exactly the same as other
+    #    platforms.
+    # 3. It is a little brittle in that Strawberry might 
+    #    one day change its layouts.  If it has and you are
+    #    reading this, please send a pull request or simply
+    #    let me know -plicease
+    require Config;
+    if($Config::Config{myuname} =~ /strawberry-perl/)
+    {
+        my($vol, $dir, $file) = File::Spec->splitpath($INC{"Config.pm"});
+        my @dirs = File::Spec->splitdir($dir);
+        splice @dirs, -3;
+        @DEFAULT_SEARCH_PATH = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+    }
+
 }
 
 my @ENV_SEARCH_PATH = split($Config{path_sep}, $ENV{PKG_CONFIG_PATH} || "");
@@ -648,6 +676,22 @@ sub get_ldflags {
     return @ret;
 }
 
+sub get_list {
+    my $self = shift;
+    my @search_paths = @{$self->search_path};
+    my @rv = ();
+    $self->recursion(0);
+    for my $d (@search_paths) {
+        next unless -d $d;
+        for my $pc (bsd_glob("$d/*.pc")) {
+            if ($pc =~ m|/([^\\\/]+)\.pc$|) {
+                $self->parse_pcfile($pc);
+                push @rv, [$1, $self->_pc_var('name') . ' - ' . $self->_pc_var('description')];
+            }
+        }
+    }
+    return @rv;
+}
 
 
 ################################################################################
@@ -773,6 +817,7 @@ GetOptions(
     'libs' => \my $PrintLibs,
     'libs-only-L' => \my $PrintLibsOnlyL,
     'libs-only-l' => \my $PrintLibsOnlyl,
+    'list-all' => \my $ListAll,
     'static' => \my $UseStatic,
     'cflags' => \my $PrintCflags,
     'exists' => \my $PrintExists,
@@ -829,8 +874,6 @@ if($PrintRealVersion) {
     exit(0);
 }
 
-my @FINDLIBS = @ARGV or die "Must specify at least one library";
-
 if($PrintErrors) {
     $quiet_errors = 0;
 }
@@ -862,7 +905,21 @@ $pc_options{print_variables} = $PrintVariables;
 $pc_options{print_values} = $PrintValues;
 $pc_options{VARS} = \%UserVariables;
 
+if($ListAll) {
+    my $o = PkgConfig->find([], %pc_options);
+    my @list = $o->get_list();
+    
+    # can't use List::Util::max as it wasn't core until Perl 5.8
+    my $max_length = 0;
+    foreach my $length (map { length $_->[0] } @list) {
+        $max_length = $length if $length > $max_length;
+    }
 
+    printf "%-${max_length}s %s\n", $_->[0], $_->[1] for @list;
+    exit(0); 
+}
+
+my @FINDLIBS = @ARGV or die "Must specify at least one library";
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
@@ -941,19 +998,18 @@ if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
 print "\n";
 exit(0);
 
+# workaround for
+# https://rt.cpan.org/Ticket/Display.html?id=96132&results=7cdf596d4e44d8f4ed9862124b28fd59
+sub run {
+    system $^X, __FILE__, @_;
+    exit $? >> 8
+}
+
 __END__
 
 =head1 NAME
 
-PkgConfig - Pure-Perl Core-Only replacement for C<pkg-config>
-
-=head1 NOTE
-
-The script is not actually installed yet (i haven't settled on a good name), but
-will decide based on input in a future version.
-
-Additionally, some dependencies are superficially included for debugging, and
-will be sanitized in a future 'release/stable' version.
+PkgConfig - Pure-Perl Core-Only replacement for pkg-config
 
 =head1 SYNOPSIS
 
@@ -967,7 +1023,8 @@ will be sanitized in a future 'release/stable' version.
     # -lgmodule-2.0 -ldl -lgthread-2.0 -pthread -lrt -lglib-2.0
 
 C<pkg-config.pl> can be used as an alias for C<ppkg-config> on platforms that
-support it.
+support it.  It can also be installed as C<pkg-config> though this is not
+recomended if your system has a nativ C<pkg-config>.
 
 Compare to:
     $ pkg-config --libs --cflags --static gio-2.0
@@ -1030,10 +1087,18 @@ Prints -L/-R part of "--libs". It defines library search path but without librar
 
 Prints the -l part of "--libs".
 
+=head4 --list-all
+
+List all know packages.
+
 =head4 --cflags
 
 (Also) print compiler and C preprocessor flags.
 
+=head4 --modversion
+
+Print the version of a given package.
+
 =head4 --static
 
 Use extra dependencies and libraries if linking against a static version of the
@@ -1196,6 +1261,41 @@ paths with those discovered by invoking L<ld(1)> and L<cpp(1)>.
 
 Currently this only works with GCC-supplied C<ld> and GNU C<ld>.
 
+=head2 INSTALL
+
+The C<Makefile.PL> that comes with C<PkgConfig> can take one or more C<--script>
+options to change of the name of the script or scripts that are installed.
+
+=over 4
+
+=item --script ppkg-config
+
+This is the default and works on all platforms
+
+=item --script pkg-config.pl
+
+This is installed by default on all platforms except for Windows, where the .pl
+may confuse the shell and cause the script to be opened in a text editor.
+
+=item --script pkg-config
+
+This is the default name of the real C<pkg-config> and so you have to specifically
+enable it if you want it.
+
+=item --script none
+
+Don't install any scripts.
+
+=back
+
+Example, install all script names:
+
+ % perl Makefile.PL --script ppkg-config --script pkg-config.pl --script pkg-config
+
+Example, don't install any scripts:
+
+ % perl Makefile.PL --script none
+
 =head2 BUGS
 
 The order of the flags is not exactly matching to that of C<pkg-config>. From my
@@ -1221,7 +1321,17 @@ perl implementation of pkg-config
 
 =item Original Author: M. Nunberg
 
-=item Current maintainer: Graham Ollis E<lt>plicease@cpan.org<Egt>
+=item Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+=back
+
+Other contributors include:
+
+=over 4
+
+=item kmx
+
+=item Sanel Zukan
 
 =back
 
